package org.gradle.api.tasks.testing

import org.gradle.util.BootstrapUtil
import org.slf4j.Logger
import org.slf4j.LoggerFactory
import org.gradle.api.tasks.compile.AbstractOptions

/**
 * @author Tom Eyckmans
 */
class AntTestNG extends AbstractAntTestTask {
    private static Logger logger = LoggerFactory.getLogger(AntTestNG);

    void execute(File compiledTestsClassesDir, List classPath, File testResultsDir, File testReportDir, List includes, List excludes, AbstractOptions testngOptions, AntBuilder ant) {
        ant.mkdir(dir: testResultsDir.absolutePath)
        createAntClassPath(ant, classPath + BootstrapUtil.antTestNGJarFiles);

        testngOptions.outputdir = testResultsDir.absolutePath;

        Map otherArgs = [
                failureProperty : FAILURES_OR_ERRORS_PROPERTY
                // skippedProperty : ??
        ]

        ant.testng(otherArgs + testngOptions.optionMap()) {
            testngOptions.jvmArgs.each {
                jvmarg(value: it)
            }
            testngOptions.systemProperties.each {String key, String value ->
                sysproperty(key: key, value: value)
            }
            testngOptions.environment.each {String key, String value ->
                env(key: key, value: value)
            }
            classfileset (dir: compiledTestsClassesDir.absolutePath ) {
                includes.each {
                    include(name: it)
                }
                excludes.each {
                    exclude(name: it)
                }
            }
        }

        ant.junitreport(todir: testResultsDir.absolutePath) {
            fileset(dir: testResultsDir.absolutePath, includes: '*.xml')
            report(todir: testReportDir.absolutePath, format: 'noframes')            
        }
    }


}